@@ -3,6 +3,7 @@ from django.db import models, transaction, connection
 from django.db.models import Q
 from django.db.models.query import QuerySet
 from django.db.utils import IntegrityError
+from django.utils import timezone
 from django.core.exceptions import MultipleObjectsReturned, ObjectDoesNotExist
 from django.conf import settings
 from vkontakte_api import fields
@@ -10,7 +11,7 @@ from vkontakte_api.utils import api_call
 from vkontakte_api.decorators import opt_generator, memoize
 from vkontakte_groups.models import Group
 from vkontakte_users.models import User
-from datetime import datetime, timedelta
+from datetime import timedelta
 import logging
 
 log = logging.getLogger('vkontakte_groups_migration')
@@ -41,8 +42,8 @@ def update_group_users(group):
     # 'IntegrityError(\'insert or update on table "vkontakte_groups_group_users" violates foreign key constraint "user_id_refs_id_5588675c"\\nDETAIL:  Key (user_id)=(...) is not present in table "vkontakte_users_user".\\n\',)'
     ids_entered_new = User.objects.filter(pk__in=ids_entered).values_list('pk', flat=True)
     if len(ids_entered_new) != len(ids_entered):
-        ids_unfetched = set(ids_entered).difference(set(ids_entered_new))
-        log.warning("Users with ids %s missed, fetch them additionally" % ids_unfetched)
+        ids_unfetched = list(set(ids_entered).difference(set(ids_entered_new)))
+        log.warning('Users with ids %s missed, fetch them additionally for the group "%s"' % (ids_unfetched, group))
         User.remote.fetch(ids=ids_unfetched)
 
     log.debug('Adding %d new users to the group "%s"' % (len(ids_entered), group))
@@ -52,7 +53,7 @@ def update_group_users(group):
     group.users.through.objects.filter(group=group, user_id__in=ids_left).delete()
 
     signals.group_users_updated.send(sender=Group, instance=group)
-    log.info('Updating m2m relations of users for group "%s" successfuly finished' % group)
+    log.info('Updating m2m relations of users for the group "%s" successfuly finished' % group)
     return True
 
 
@@ -128,7 +129,7 @@ class GroupMigrationManager(models.Manager, GroupMigrationQueryset):
             yield (offset+len(ids), response['count'], offset_step)
 
         # save stat with time and other fields
-        stat.time = datetime.now()
+        stat.time = timezone.now()
         stat.save_final()
         signals.group_migration_updated.send(sender=GroupMigration, instance=stat)
 
